@@ -6,8 +6,9 @@
 #' @param ... Not used argument.
 #' @details This function makes it easier to use the results to make a prediction or to see the fitted model.
 #' @return The object returned depends the functions.
-#' @author Wenchuan Guo <wguo007@ucr.edu>
-#' @seealso \code{coef} method and \code{l0ara} function.
+#' @author
+#' Wenchuan Guo <wguo007@ucr.edu>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
+#' @seealso \code{\link{coef}} method and \code{\link{l0ara}} function.
 #' @export
 predict.l0ara <- function(object, newx, type=c("link", "response", "coefficients", "class"), ...){
   type <- match.arg(type)
@@ -35,8 +36,9 @@ predict.l0ara <- function(object, newx, type=c("link", "response", "coefficients
 #' @param ... Not used argument.
 #' @details This function makes it easier to use the results to make a prediction or to see the fitted model.
 #' @return The object returns the coefficients.
-#' @author Wenchuan Guo <wguo007@ucr.edu>
-#' @seealso \code{predict} method and \code{l0ara} function.
+#' @author
+#' Wenchuan Guo <wguo007@ucr.edu>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
+#' @seealso \code{\link{predict}} method and \code{\link{l0ara}} function.
 #' @export
 coef.l0ara <- function(object, ...){
   coefs <- as.vector(object$beta)
@@ -52,8 +54,9 @@ coef.l0ara <- function(object, ...){
 #' @param ... Not used argument.
 #' @details This function fit the model with the optimal \code{lambda} first and then print the coefficients. This function makes it easier to use the results to make a prediction or to see the fitted model.
 #' @return The object returns the coefficients.
-#' @author Wenchuan Guo <wguo007@ucr.edu>
-#' @seealso \code{predict} method and \code{l0ara} function.
+#' @author
+#' Wenchuan Guo <wguo007@ucr.edu>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
+#' @seealso \code{\link{predict}} method and \code{\link{l0ara}} function.
 #' @export
 coef.cv.l0ara <- function(object, ...){
   fit <- l0ara(object$x, object$y, object$family, object$lam.min)
@@ -70,8 +73,9 @@ coef.cv.l0ara <- function(object, ...){
 #' @param x Fitted "l0ara" object.
 #' @param ... Not used argument.
 #' @details This function makes it easier to see the fitted model.
-#' @author Wenchuan Guo <wguo007@ucr.edu>
-#' @seealso \code{predict}, \code{coef} methods and \code{l0ara} function.
+#' @author
+#' Wenchuan Guo <wguo007@ucr.edu>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
+#' @seealso \code{\link{predict}}, \code{\link{coef}} methods and \code{\link{l0ara}} function.
 #' @export
 print.l0ara <- function(x, ...){
   family <- switch(x$family, gaussian = "Linear regression", logit = "Logistic regression", poisson = "Poisson regression", inv.gaussian = "Inverse gaussian regression", gamma = "Gamma regression" )
@@ -85,14 +89,15 @@ print.l0ara <- function(x, ...){
 #' @description Print the general information of the cross validated fit.
 #' @param x Fitted "cv.l0ara" object.
 #' @param ... Not used argument.
-#' @details This function makes it easier to see the cross validation results.
-#' @author Wenchuan Guo <wguo007@ucr.edu>
-#' @seealso \code{predict}, \code{coef} methods and \code{l0ara} function.
+#' @details This function makes it easier to see the cross-validation results.
+#' @author
+#' Wenchuan Guo <wguo007@ucr.edu>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
+#' @seealso \code{\link{predict}}, \code{\link{coef}} methods and \code{\link{l0ara}} function.
 #' @export
 print.cv.l0ara <- function(x, ...){
   measure <- switch(x$measure, mse = "Mean square error", mae = "Mean absolute error", class = "Misclassification rate", auc = "Area under the curve")
   family <- switch(x$family, gaussian = "Linear regression", logit = "Logistic regression", poisson = "Poisson regression", inv.gaussian = "Inverse gaussian regression", gamma = "Gamma regression" )
-  cat("Number of Lambda used : ", length(x$lam), "\n")
+  cat("Number of Lambda used : ", length(x$lambda), "\n")
   cat("Optimal Lambda : ", x$lam.min, "\n")
   cat("Model : ", family, "\n")
   cat("Measure : ", measure, "\n")
@@ -106,8 +111,9 @@ print.cv.l0ara <- function(x, ...){
 #' @param split logical; if if \code{TRUE}, produces seperate plots.
 #' @param col color of the dots.
 #' @param ... Not used argument.
-#' @author Wenchuan Guo <wguo007@ucr.edu>
-#' @seealso \code{predict}, \code{coef} methods and \code{l0ara} function.
+#' @author
+#' Wenchuan Guo <wguo007@ucr.edu>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
+#' @seealso \code{\link{predict}}, \code{\link{coef}} methods and \code{\link{l0ara}} function.
 #' @export
 plot.l0ara <- function(x, auc = FALSE, split = FALSE, col = 4, ...){
   nplots <- ifelse(auc, 2, 1)
@@ -131,7 +137,7 @@ plot.l0ara <- function(x, auc = FALSE, split = FALSE, col = 4, ...){
       tp[i] <- mean(pred[x$y==1]==1)
       area[i] <- (tp[i]-fp[i]+1)/2
     }
-    plot(NA, xlab="False positive rate", ylab="True positive rate", xlim=c(0,1), ylim=c(0,1), main=paste("ROC curve for lambda =", x$lam), sub = paste("max auc = ", round(max(area), 2), ";", "threshold = ", round(thres[which.max(area)],2)), ...)
+    plot(NA, xlab="False positive rate", ylab="True positive rate", xlim=c(0,1), ylim=c(0,1), main=paste("ROC curve for lambda =", x$lam), sub = paste("max auc = ", round(max(area), 2), ";", "best cut-off = ", round(thres[which.max(area)],2)), ...)
     lines(fp, tp, pch=19, col=col, type="b", lty=2)
   }
 }
@@ -141,8 +147,9 @@ plot.l0ara <- function(x, auc = FALSE, split = FALSE, col = 4, ...){
 #' @param x Fitted "cv.l0ara" object.
 #' @param col color of the dots.
 #' @param ... Not used argument.
-#' @author Wenchuan Guo <wguo007@ucr.edu>
-#' @seealso \code{predict}, \code{coef} methods, \code{cv.l0ara} and \code{l0ara} function.
+#' @author
+#' Wenchuan Guo <wguo007@ucr.edu>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
+#' @seealso \code{\link{predict}}, \code{\link{coef}} methods, \code{\link{cv.l0ara}} and \code{\link{l0ara}} function.
 #' @export
 
 plot.cv.l0ara <- function(x, col = 3, ...) {
